@@ -1,5 +1,5 @@
 package Bio::Roary::AssemblyStatistics;
-$Bio::Roary::AssemblyStatistics::VERSION = '3.6.8';
+$Bio::Roary::AssemblyStatistics::VERSION = '3.7.0';
 # ABSTRACT: Given a spreadsheet of gene presence and absence calculate some statistics
 
 
@@ -34,7 +34,7 @@ sub BUILD {
 sub _build_logger
 {
     my ($self) = @_;
-    Log::Log4perl->easy_init(level => $ERROR);
+    Log::Log4perl->easy_init( $ERROR );
     my $logger = get_logger();
     return $logger;
 }
@@ -212,7 +212,7 @@ Bio::Roary::AssemblyStatistics - Given a spreadsheet of gene presence and absenc
 
 =head1 VERSION
 
-version 3.6.8
+version 3.7.0
 
 =head1 SYNOPSIS
 
