@@ -1,5 +1,5 @@
 package Bio::Roary::ReformatInputGFFs;
-$Bio::Roary::ReformatInputGFFs::VERSION = '3.6.8';
+$Bio::Roary::ReformatInputGFFs::VERSION = '3.7.0';
 # ABSTRACT: Take in gff files and add suffix where a gene id is seen twice
 
 
@@ -21,7 +21,7 @@ has 'fixed_gff_files' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] }
 
 sub _build_logger {
     my ($self) = @_;
-    Log::Log4perl->easy_init( level => $ERROR );
+    Log::Log4perl->easy_init( $ERROR );
     my $logger = get_logger();
     return $logger;
 }
@@ -161,7 +161,7 @@ Bio::Roary::ReformatInputGFFs - Take in gff files and add suffix where a gene id
 
 =head1 VERSION
 
-version 3.6.8
+version 3.7.0
 
 =head1 SYNOPSIS
 
